#
# spec file for package offlineimap
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?_userunitdir:%define _userunitdir /usr/lib/systemd/user}

Name:           offlineimap
Version:        7.0.8
Release:        1.2
Summary:        Powerful IMAP/Maildir Synchronization Tool
License:        GPL-2.0+
Group:          Productivity/Networking/Email/Utilities
Url:            http://offlineimap.org/
Source0:        https://github.com/OfflineIMAP/offlineimap/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source100:      offlineimap-rpmlintrc
BuildRequires:  asciidoc
BuildRequires:  docutils
BuildRequires:  libxml2-tools
BuildRequires:  libxslt-tools
BuildRequires:  python
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  python-six
BuildRequires:  python-sphinx
BuildRequires:  systemd-rpm-macros
Requires:       ca-certificates
Requires:       python
Requires:       python-curses
Suggests:       %{name}-htmldoc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
OfflineIMAP is a tool to synchronize IMAP and Maildir mailboxes which is very
fast due to its multithreaded synchronization algorithm.  It offers several
user interfaces and is generally very configurable providing a great number of
settings for controlling its behavior, tuning performance.  Specifically, there
are several sophisticated and flexible mechanisms for determining the list of
maiilboxes to synchronize.  Furthermore, it supports internal or external
automation, SSL and PREAUTH tunnels, offline (or "unplugged") reading, and a
variety of esoteric IMAP features for compatibility with the widest variety of
IMAP servers.  OfflineIMAP is designed for safety in terms of avoiding the loss
of mails under any circumstances.

%package htmldoc
Summary:        Html documentation for %{name}
Group:          Documentation/HTML

%description htmldoc
Separated documentation from %{name} package

%prep
%setup -q
sed -i '/^#!\/usr\/bin\/env/d' offlineimap/bundled_imaplib2.py

%build
python setup.py build
make %{?_smp_mflags} V=1 -C docs

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot} \
    --record-rpm=INSTALLED_FILES

rm -rf docs/html/_sources \
    docs/html/.buildinfo \
    objects.inv

mkdir examples
mv offlineimap.conf* examples

install -D -m 644 docs/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1
install -D -m 644 docs/%{name}ui.7 %{buildroot}%{_mandir}/man7/%{name}ui.7
install -D -m 444 contrib/systemd/mail.target %{buildroot}%{_userunitdir}/mail.target
install -D -m 444 contrib/systemd/%{name}.service %{buildroot}%{_userunitdir}/%{name}.service
install -D -m 444 contrib/systemd/%{name}.timer %{buildroot}%{_userunitdir}/%{name}.timer
install -D -m 444 contrib/systemd/%{name}@.service %{buildroot}%{_userunitdir}/%{name}@.service
install -D -m 444 contrib/systemd/%{name}@.timer %{buildroot}%{_userunitdir}/%{name}@.timer

%files -f INSTALLED_FILES
%defattr(-,root,root)
%doc COPYING Changelog.md README.md examples
%{_mandir}/man1/%{name}.1*
%{_mandir}/man7/offlineimapui.7*
%dir %{_userunitdir}
%{_userunitdir}/mail.target
%{_userunitdir}/%{name}.service
%{_userunitdir}/%{name}.timer
%{_userunitdir}/%{name}@.service
%{_userunitdir}/%{name}@.timer

%files htmldoc
%defattr(-,root,root)
%doc docs/html

%changelog
* Thu Oct 13 2016 mimi.vx@gmail.com
- update to 7.0.8
- Import ui before threadutil to resolve circular dependency
- Fix implicit call to unicode() from UI functions.
- imapserver: minor code cleaning
* Sun Sep 25 2016 mimi.vx@gmail.com
- update to 7.0.7
  * Remove EXPERIMENTAL flag for the singlethreadperfolder configuration option.
  * Ensure logs are in bytes for PLAIN authentication.
  * Minor: utils: distro: fix copyright line.
  * README: minor copy edits.
  * IDLE: protect all calls to imapobj.noop() (coonection might be dropped).
  * XOAUTH2: raise error if string 'error' is in the response.
  * Set singlethreadperfolder configuration option when in idle mode.
  * repository: IMAP: cache the idle folders in memory.
  * mbnames: add info output messages in dry run mode.
  * mbnames: remove non-required argument.
  * offlineimap.conf: explain hooks in idle mode.
  * Explain how to submit issues in more files.
* Tue Aug 23 2016 mimi.vx@gmail.com
- update to 7.0.6
  * XOAUTH2: improve error message while trying to get access token.
  * Show python version for -V CLI option.
  * offlineimap.conf: add note about Gmail\All Mail keeping the emails while deleted.
* Sun Aug 14 2016 mimi.vx@gmail.com
- add systemd user services
* Sun Aug 14 2016 mimi.vx@gmail.com
- update to 7.0.5
- separated Html doc to own package
  * ConfigHelperMixin must be new-style class to not break inheritance.
  * don't delete messages in local cache in dry-run mode.
  * Fix typo in format string in machineui.
  * folder: IMAP: change raw assert to OfflineImapError
  * folder: IMAP: add 'imap' debug output before calling FETCH.
  * explicitly set hash of Base class to None.
  * imapserver: change lambdas with map to list comprehension.
  * Clarify which settings are required for mbnames.
  * Remove an unused import.
  * folder: Base: minor style fix.
* Mon Aug  1 2016 mimi.vx@gmail.com
- update to 7.0.3
  * very long upstream changelog, please see Changelog.md file in docs
* Sat May 16 2015 gber@opensuse.org
- update to version 6.5.7
  - better documentation for Windows users
  - contrib/release.sh (v0.2): fixes and improvements
  - report exceptions via exit code.
  - proxy feature leaks DNS support: offlineimap.conf talks about
    this
  - email parsing for date coudn't work: fix datetuple dst check
  - little code refactoring
- drop offlineimap-use-system-certificates.patch, upstream solved
  this differently by requiring users to specify "OS-DEFAULT"
  in order to use the system CA bundle, this fixes a problem raised
  in boo#907035 where users are unable to just check the
  certificate fingerprint
* Tue Nov 25 2014 gber@opensuse.org
- add offlineimap-use-system-certificates.patch in order to use
  system certificates by default and rquire ca-certificates
  (boo#907035)
- add missing explicit dependency on python-setuptools
* Sun May 25 2014 gber@opensuse.org
- update to version 6.5.6
  * Add knob to filter some headers before uploading message to
    IMAP server (Abdó Roig-Maranges)
  * Allow to sync GMail labels and implement GmailMaildir
    repository that adds mechanics to change message labels (Abdó
    Roig-Maranges)
  * Allow to migrate status data across differend backends (Abdó
    Roig-Maranges)
  * Support XDG Base Directory Specification (if
    $XDG_CONFIG_HOME/offlineimap/config exists, use it as the
    default configuration path; ~/.offlineimaprc is still tried
    after XDG location) (GitHub#32)
  * Allow multiple certificate fingerprints to be specified inside
    'cert_fingerprint'
* Sat Oct  5 2013 gber@opensuse.org
- update to version 6.5.5
  * Avoid lockups for IMAP synchronizations running with the
    "-1" command-line switch (X-Ryl669 <boite.pour.spam@gmail.com>)
  * Dump stacktrace for all threads on SIGQUIT: ease debugging
    of threading and other issues
  * SIGHUP is now handled as the termination notification rather
    than the signal to reread the configuration (Dmitrijs Ledkovs)
  * Honor the timezone of emails (Tobias Thierer)
  * Allow mbnames output to be sorted by a custom sort key by
    specifying a 'sort_keyfunc' function in the [mbnames] section
    of the config.
  * Support SASL PLAIN authentication method.  (Andreas Mack)
  * Support transport-only tunnels that requre full IMAP
    authentication.  (Steve Purcell)
  * Make the list of authentication mechanisms to be configurable.
    (Andreas Mack)
  * Allow to set message access and modification timestamps based
    on the "Date" header of the message itself.  (Cyril Russo)
  * "peritem" format string for [mbnames] got new expansion key
    "localfolders" that corresponds to the same parameter of the
    local repository for the account being processed.
  * [regression] pass folder names to the foldersort function,
    revert the documented behaviour
  * Fix handling of zero-sized IMAP data items (GitHub#15).
  * Updated bundled imaplib2 to 2.35:
  - fix for Gmail sending a BYE response after reading >100
    messages in a session;
  - includes fix for GitHub#15: patch was accepted upstream.
  * Updated bundled imaplib2 to 2.36: it includes support for SSL
    version override that was integrated into our code before,
    no other changes.
  * Fixed parsing of quoted strings in IMAP responses: strings like
    "\\" were treated as having \" as the escaped quote, rather
    than treating it as the quoted escaped backslash (GitHub#53).
  * Execute pre/post-sync hooks during synchronizations toggled by
    IMAP IDLE message processing. (maxgerer@gmail.com)
  * Catch unsuccessful local mail uploads when IMAP server responds
    with "NO" status; that resulted in a loss of such local
    messages. (Adam Spiers)
  * Don't create folders if readonly is enabled.
  * Learn to deal with readonly folders to properly detect this
    condition and act accordingly.  One example is Gmail's "Chats"
    folder that is read-only, but contains logs of the quick chats.
    (E.  Ryabinkin)
  * Fix str.format() calls for Python 2.6 (D. Logie)
  * Remove APPENDUID hack, previously introduced to fix Gmail, no
    longer necessary, it might have been breaking things. (J.
    Wiegley)
  * Improve regex that could lead to 'NoneType' object has no
    attribute 'group' (D. Franke)
  * Improved error throwing on repository misconfiguration
  * bump bundled imaplib2 library 2.29 --> 2.33
  * Actually perform the SSL fingerprint check (reported by J.
    Cook)
  * Curses UI, don't use colors after we shut down curses already
    (C.Höger)
  * Document that '%%' needs encoding as '%%%%' in configuration
    files.
  * Fix crash when IMAP.quickchanged() led to an Error (reported by
    sharat87)
  * Implement the createfolders setting to disable folder
    propagation (see docs)
* Fri Jun 28 2013 gber@opensuse.org
- (build) depend on python since offlineimap requires the ssl
  module
* Mon Apr  9 2012 gber@opensuse.org
- update to version 6.5.3
  * --dry-run mode protects us from performing any actual action
  * internal code changes to prepare for Python3
  * improve user documentation of nametrans/folderfilter
  * fixed some cases where invalid nametrans rules were not caught
    and we would not propagate local folders to the remote
    repository
  * revert "* Slight performance enhancement uploading mails to an
    IMAP server in the common case.", it might have led to
    instabilities
  * revamped documentation structure, `make` in the `docs` dir or
    `make doc` in the root dir will now create the 1) man page and
    2) the user documentation using sphinx
  * -f command line option only works on the untranslated remote
    repository folder names now
  * some better output when using nonsensical configuration
    settings
  * improve compatability of the curses UI with python 2.6
* Sun Feb  5 2012 gber@opensuse.org
- update to version 6.5.2.1
  * fix python2.6 compatibility with the TTYUI backend (crash)
  * fix TTYUI regression from 6.5.2 in refresh loop (crash)
  * fix crashes related to UIDVALIDITY returning "None"
  * make folders containing quotes work rather than crashing
  * remove the Gmail "realdelete" option, as it could lead to
    potential data loss.
  * improve delete msg performance with SQLITE backend
  * enforce basic UI when using the --info switch
  * beginning of a test suite
* Tue Jan 17 2012 gber@opensuse.org
- update to version 6.5.2
  * user documentation is now integrated in
    http://docs.offlineimap.org
  * Gmail "realdelete" option is considered harmful and has the
    potential for data loss (see
    http://article.gmane.org/gmane.mail.imap.offlineimap.general/5265)
  * rather than write out the nametrans'lated folder names for
    mbnames, we now write out the local untransformed box names,
    this became relevant since we support nametrans rules on the
    local side since only a short time
  * some sanity checks and improved error messages
  * revert 6.5.1.1 change to use public imaplib2 function, it was
    reported to not always work
  * don't fail when ~/netrc is not readable by us
  * don't emit noisy regular sleeping announcements in Basic UI
* Sun Jan  8 2012 gber@opensuse.org
- update to version 6.5.1.2
  * Fix possible crash during --info run
  * Fix reading in Maildirs, where we would attempt to create empty
    directories on REMOTE
  * Do not attempt to sync lower case custom Maildir flags. We do
    not support them (yet) (this prevents many scary bogus sync
    messages)
  * Add filter information to the filter list in --info output
* Sat Jan  7 2012 gber@opensuse.org
- update to version 6.5.1.1:
  * Sleep led to crash ('abort_signal' not existing)
  * Make exit via 'q' key work again cleanly
- changes in 6.5.1:
  * Fixed Maildir regression "flagmatchre" not found
  * Have console output go by default to STDOUT and not STDERR
  * Fixed MachineUI to urlencode() output lines again, rather than
    outputting multi-line items. It's ugly as hell, but it had been
    that way for years
  * Remove the old global locking system. We lock only the accounts
    that we currently sync, so you can invoke OfflineImap multiple
    times now as long as you sync different accounts. This system
    is compatible with all releases >= 6.4.0, so don't run older
    releases simultanous to this one
- changes in 6.5.0:
  * CRITICAL bug fix release for 6.4.x series which had bugs
    potentially causing data loss:
  * Uploading multiple emails to an IMAP server would lead to
    wrong UIDs being returned (ie the same for all), which
    confused offlineimap and led to recurrent upload/download
    loops and inconsistencies in the IMAP<->IMAP uid mapping
  * Uploading of Messages from Maildir and IMAP<->IMAP has been
    made more efficient by renaming files/mapping entries, rather
    than actually loading and saving the message under a new UID
  * Fix regression that broke MachineUI
- changes in 6.4.4:
  * Fix the missing folder error that occured when a new remote
    folder was detected (IMAP<->Maildir)
  * Possibly fixed bug that prevented us from ever re-reading
    Maildir folders, so flag changes and deletions were not
    detected when running in a refresh loop. This is a regression
    that was introduced in about 6.4.0
  * Never mangle maildir file names when using nonstandard Maildir
    flags (such as 'a'), note that they will still be deleted as
    they are not supported in the sync to an IMAP server
- changes in 6.4.3:
  * add a --info command line switch that outputs useful
    information about the server and the configuration for all
    enabled accounts
  * Reworked logging which was reported to e.g. not flush output to
    files often enough. User-visible changes:
    a) console output goes to stderr (for now)
    b) file output has timestamps and looks identical in the basic
    and ttyui UIs
    c) File output should be flushed after logging by default (do
    report if not)
  * Bumped bundled imaplib2 to release 2.29
  * Make ctrl-c exit cleanly rather aborting brutally (which could
    leave around temporary files, half-written cache files, etc).
    Exiting on SIGTERM and CTRL-C can take a little longer, but
    will be clean
- changes in 6.4.2:
  * IMAP<->IMAP sync with a readonly local IMAP repository failed
    with a rather mysterious "TypeError: expected a character
    buffer object" error. Fix this my retrieving the list of
    folders early enough even for readonly repositories
  * Fix regression from 6.4.0. When using local Maildirs with "/"
    as a folder separator, all folder names would get a trailing
    slash appended, which is plain wrong
- changes in 6.4.1:
  * Indicate progress when copying many messages (slightly change
    log format)
  * Output how long an account sync took (min:sec)
  * Syncing multiple accounts in single-threaded mode would fail as
    we try to "register" a thread as belonging to two accounts
    which was fatal. Make it non-fatal (it can be legitimate)
  * New folders on the remote would be skipped on the very sync run
    they are created and only by synced in subsequent runs. Fixed
  * a readonly parameter to select() was not always treated
    correctly, which could result in some folders being opened
    read-only when we really needed read-write
* Sun Dec 11 2011 cthiel@suse.com
- update to version 6.4.0
  * Various regression and bug fixes from the last couple of RCs
  * Refresh server capabilities after login, so we know that Gmail
    supports UIDPLUS (it only announces that after login, not
    before). This prevents us from adding custom headers to Gmail uploads.
  * Fix the creation of folders on remote repositories, which was still
    botched on rc2.
  * Implement per-account locking, so that it will possible to sync
    different accounts at the same time. The old global lock is still in
    place for backward compatibility reasons (to be able to run old and
    new versions of OfflineImap concurrently) and will be removed in the
    future. Starting with this version, OfflineImap will be
    forward-compatible with the per-account locking style.
  * Implement RFC 2595 LOGINDISABLED. Warn the user and abort when we
    attempt a plaintext login but the server has explicitly disabled
    plaintext logins rather than crashing.
  * Folders will now also be automatically created on the REMOTE side of
    an account if they exist on the local side. Use the folderfilters
    setting on the local side to prevent some folders from migrating to
    the remote side.  Also, if you have a nametrans setting on the remote
    repository, you might need a nametrans setting on the local repository
    that leads to the original name (reverse nametrans).
  * Documentation improvements concerning 'restoreatime' and some code cleanup
  * Maildir repositories now also respond to folderfilter= configurations.
  * New emails are not created with "-rwxr-xr-x" but as "-rw-r--r--"
    anymore, fixing a regression in 6.3.4.
  * When a message upload/download fails, we do not abort the whole folder
    synchronization, but only skip that message, informing the user at the
    end of the sync run.
  * If you connect via ssl and 'cert_fingerprint' is configured, we check
    that the server certificate is actually known and identical by
    comparing the stored sha1 fingerprint with the current one.
  * Refactor our IMAPServer class. Background work without user-visible
    changes.
  * Remove the configurability of the Blinkenlights statuschar. It
    cluttered the main configuration file for little gain.
  * Updated bundled imaplib2 to version 2.28.
  * We protect more robustly against asking for inexistent messages from the
    IMAP server, when someone else deletes or moves messages while we sync.
  * Selecting inexistent folders specified in folderincludes now throws
    nice errors and continues to sync with all other folders rather than
    exiting offlineimap with a traceback.
- changes in v6.3.4
  * Handle when UID can't be found on saved messages.
  * Support maildir for Windows.
  * Manual improved.
  * Added StartTLS support, it will automatically be used if the server
    supports it.
  * We protect more robustly against asking for inexistent messages from the
    IMAP server, when someone else deletes or moves messages while we sync.
  * Implement experimental IDLE feature.
  * Maildirs use less memory while syncing.
  * Saving to Maildirs now checks for file existence without race conditions.
  * A bug in the underlying imap library has been fixed that could
    potentially lead to data loss if the server interrupted responses with
    unexpected but legal server status responses. This would mainly occur
    in folders with many thousands of emails. Upgrading from the previous
    release is strongly recommended.
  * Begin sphinx-based documentation for the code.
  * Enable 1-way synchronization by settting a [Repository ...] to
    readonly = True. When e.g. using offlineimap for backup purposes you
    can thus make sure that no changes in your backup trickle back into
    the main IMAP server.
  * Optional: experimental SQLite-based backend for the LocalStatus
    cache. Plain text remains the default.
  * Start a enhanced error handling background system. This is designed to not
    stop a whole sync process on all errors (not much used, yet).
  * Documentation improvements: the FAQ wins new entries and add a new HACKING
    file for developers.
  * Lot of code cleanups.
  * Reduced our sync logic from 4 passes to 3 passes (integrating upload of
    "new" and "existing" messages into one function). This should result in a
    slight speedup.
  * No whitespace is stripped from comma-separated arguments passed via
    the -f option.
  * Give more detailed error when encountering a corrupt UID mapping file.
  * Drop connection if synchronization failed. This is needed if resuming the
    system from suspend mode gives a wrong connection.
  * Fix the offlineimap crash when invoking debug option 'thread'.
  * Make 'thread' command line option work.
* Sat Dec  3 2011 puzel@suse.com
- require python-curses to make BlinkenLights UI work out of the
  box
* Sat May 28 2011 gber@opensuse.org
- update to version 6.3.3
  * the -f option now works with Folder names with spaces when
    quoted
  * improved documentation
  * increased compatability with Gmail servers which claim to not
    support the UIDPLUS extension but in reality do
  * implemented UIDPLUS extension support
  * SSL: support subjectAltName
  * use imaplib2 instead of imaplib
  * Makefile use magic to find the version number
  * Rework the repository module
  * Change UI names to Blinkenlights,TTYUI,Basic,Quiet,MachineUI,
    old names will still work but are deprecated
  * reworked the syncing strategy, the only user-visible change is
    that blowing away LocalStatus will not require you to
    redownload ALL of your mails if you still have the local
    Maildir, it will simply recreate LocalStatus
  * TTYUI ouput improved
  * refactoring and code cleanups
- changes from 6.3.2
  * sample offlineimap.conf states it expects a PEM formatted
    certificate
  * give better trace information if an error occurs
  * have --version ONLY print the version number
  * Makefile learned to build the package and make it the default
  * introduced a Changelog to involve community in the releasing
    process
  * migrated documentation to restructured text
  * improved CustomConfig documentation
  * use single threading mode in debug mode exept for "-d thread"
  * allow UI to have arbitrary names
  * improved version managment and make it easier
  * introduced a true single threading mode
  * primitive implementation of SSL certificates check
  * use OptionParser instead of getopts
  * code cleanups and bugfixes
- changes from 6.3.1
  * cProfile becomes the default profiler
  * UI output formating enhanced
  * code cleanup and bugfixes
- changes from 6.3.0
  * netrc password authentication
  * user name querying from netrc
- cleaned up specfile and improved summary/description
* Wed Dec 15 2010 gregkh@suse.de
- update to 6.2.0.2 from the offlineimap git tree
* Sat Jun 19 2010 bernhard@bwalle.de
- Add a patch to fix the Python SSL deprecation warning that is
  always displayed on startup.
* Thu Dec 31 2009 guido+opensuse.org@berhoerster.name
- update to version 6.2.0
  * removed imaplib2 which was the cause of numerous hang/crash bugs
  * removed IDLE support due to removal of imaplib2
- changes in version 6.1.2
  * reduced memory usage when scanning Maildirs
  * bugfixes
- changes in version 6.1.1
  * fixed minimum Python version
- changes in version 6.1.0
  * order of syncing can now be specified
  * support for pre/post-sync hooks
  * option to only sync subscribed IMAP folders
  * support for forcing a sync through sending a signal
  * support for IMAP IDLE
  * support overriding keepalive by user if imapfolders set.
  * support /etc/netrc in addition to ~/.netrc
  * bugfixes
- changed summary to silence rpmlint
- build noarch package if supported
- added rpmlintrc to fix bogus python-naming-policy-not-applied warning
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Thu Aug 14 2008 cthiel@suse.de
- update to version 6.0.3
  * Removed call to task_done, which required Python 2.5.
  * Make GMail trash and spam folder names configurable -- German Google
    Mail uses different folder names.
- changes in version 6.0.2
  * Yew more power handling improvements.
- changes in version 6.0.1
  * Add support for SSL client certificates.
  * Yet another tweak for maildir creations.
  * Added new [general] config option fsync to permit disabling of fsync
    when desired.
  * Improve OfflineIMAP power profile by reworking threadutil.
* Tue May 20 2008 cthiel@suse.de
- update to version 6.0.0
  * New features include re-scanning remote folder names at every sync run,
    new machine-parsable user interface, PID file generation, new -q (quick)
    option, Maildir performance increases, support for username/password in
    netrc file, new -f option for syncing only selected folders, new -k
    option to override config options, new special support for GMail, new
    Kerberos support.
  * Code cleanups include dropping internal imaplib.py, dropping all Tk
    interfaces.
  * Bug fixes include improved interaction with Dovecot, improved filesystem
    syncing, UID validitiy diagnostics improvement, preauthtunnel cleanups,
    potential Maildir race fix, fixes for servers that return UIDs in some
    but not all FETCH responses, better read-only support, enhancements when
    local folders are deleted.
* Sun Dec  3 2006 cthiel@suse.de
- update to version 4.0.16
  * Apply patches from Danial Burrows to improve situation when errors
    occur.
  * Fixed a bug that could cause OfflineIMAP to crash when copying a message
    from a remote server that didn't have an INTERNALDATE.
  * Part of the FAQ from the manual has been moved to the OfflineIMAP wiki
    at http://software.complete.org/offlineimap.  New file FAQ.html is a
    dump of that page.
  * Corrected outdated bug reporting info in the manual.
* Thu Nov 30 2006 cthiel@suse.de
- update to version 4.0.15
  * Applied patch from Aaron Schrab to sync INTERNALDATEs.  As a nice
    side-effect, this should finally resolve the problem with bad dates on
    spams.
  * Noted new homepage at http://software.complete.org/offlineimap/
  * Updated copyright dates
* Sun Oct  1 2006 cthiel@suse.de
- initial package (version 4.0.14)
